@@ -31,8 +31,8 @@ class Daemonize(object):
         self.logger.setLevel(logging.DEBUG)
         # Display log messages only on defined handlers.
         self.logger.propagate = False
-        # It will work on OS X and Linux.  No FreeBSD support, guys, I don't
-        # want to import re here to parse your peculiar platform string.
+        # It will work on OS X and Linux. No FreeBSD support, guys, I don't want to import re here
+        # to parse your peculiar platform string.
         if sys.platform == "darwin":
             syslog_address = "/var/run/syslog"
         else:
@@ -60,29 +60,27 @@ class Daemonize(object):
         # Fork, creating a new process for the child.
         process_id = os.fork()
         if process_id < 0:
-            # Fork error.  Exit badly.
+            # Fork error. Exit badly.
             sys.exit(1)
         elif process_id != 0:
-            # This is the parent process.  Exit.
+            # This is the parent process. Exit.
             sys.exit(0)
-        # This is the child process.  Continue.
+        # This is the child process. Continue.
 
         # Stop listening for signals that the parent process receives.
         # This is done by getting a new process id.
         # setpgrp() is an alternative to setsid().
-        # setsid puts the process in a new parent group and detaches its
-        # controlling terminal.
+        # setsid puts the process in a new parent group and detaches its controlling terminal.
         process_id = os.setsid()
         if process_id == -1:
             # Uh oh, there was a problem.
             sys.exit(1)
 
-        # Close all file descriptors, except the ones mentioned in
-        # self.keep_fds.
+        # Close all file descriptors, except the ones mentioned in self.keep_fds.
         devnull = "/dev/null"
         if hasattr(os, "devnull"):
-            # Python has set os.devnull on this system, use it instead
-            # as it might be different than /dev/null.
+            # Python has set os.devnull on this system, use it instead as it might be different
+            # than /dev/null.
             devnull = os.devnull
 
         for fd in range(resource.getrlimit(resource.RLIMIT_NOFILE)[0]):
@@ -96,26 +94,21 @@ class Daemonize(object):
         os.dup(0)
         os.dup(0)
 
-        # Set umask to default to safe file permissions when running
-        # as a root daemon.  027 is an octal number.
-        os.umask(027)
+        # Set umask to default to safe file permissions when running as a root daemon. 027 is an
+        # octal number which we are typing as 0o27 for Python3 compatibility.
+        os.umask(0o27)
 
-        # Change to a known directory.  If this isn't done, starting
-        # a daemon in a subdirectory that needs to be deleted results
-        # in "directory busy" errors.
-        # On some systems, running with chdir("/") is not allowed,
-        # so this should be settable by the user of this library.
+        # Change to a known directory. If this isn't done, starting a daemon in a subdirectory that
+        # needs to be deleted results in "directory busy" errors.
         os.chdir("/")
 
-        # Create a lockfile so that only one instance of this daemon
-        # is running at any time.
+        # Create a lockfile so that only one instance of this daemon is running at any time.
         lockfile = open(self.pid, "w")
-        # Try to get an exclusive lock on the file.  This will fail
-        # if another process has the file locked.
+        # Try to get an exclusive lock on the file. This will fail if another process has the file
+        # locked.
         fcntl.lockf(lockfile, fcntl.LOCK_EX | fcntl.LOCK_NB)
 
-        # Record the process id to the lockfile.  This is standard
-        # practice for daemons.
+        # Record the process id to the lockfile. This is standard practice for daemons.
         lockfile.write("%s" % (os.getpid()))
         lockfile.flush()
 
